@@ -6,7 +6,7 @@
 ;; URL: http://github.com/s-kostyaev/elisa
 ;; Keywords: help local tools
 ;; Package-Requires: ((emacs "29.2") (ellama "0.11.2") (llm "0.18.1") (async "1.9.8") (plz "0.9"))
-;; Version: 1.1.4
+;; Version: 1.1.5
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;; Created: 18th Feb 2024
 
@@ -1358,7 +1358,7 @@ It does nothing if buffer file not inside one of existing collections."
 	  (cl-remove col elisa-enabled-collections :test #'string=))))
 
 ;;;###autoload
-(defun elisa-disble-all-collections ()
+(defun elisa-disable-all-collections ()
   "Disable all collections."
   (interactive)
   (mapc #'elisa-disable-collection elisa-enabled-collections))
